# ever-playground

A tool alternative to Fift: play with Cells, Slices, Builders, and Dictionaries — native types of TVM; assemble and run TVM code.

### Running examples in dev mode

```
python3 -m venv .venv
source .venv/bin/activate
pip install maturin
maturin develop
python3 examples.py
```

### Running examples (TODO)

```
pip install ever-playground
python3 examples.py
```
